==> nextcloud-25.0.8.tgz: nextcloud/apps/files_external/l10n/sq.js <==
OC.L10N.register(
    "files_external",
    {
    "External storage" : "Depozitë e jashtme",
    "Personal" : "Personale",
    "System" : "Sistem",
    "Grant access" : "Akordoji hyrje",
    "Error configuring OAuth1" : "Gabim gjatë formësimit të OAuth1",
    "Please provide a valid app key and secret." : "Ju lutemi jepni një kyç dhe një të fshehtë aplikacioni të vlefshme.",
    "Error configuring OAuth2" : "Gabim gjatë formësimit të OAuth2",
    "Generate keys" : "Prodho kyçe",
    "Error generating key pair" : "Gabim gjatë prodhimit të çiftit të kyçeve",
    "Compatibility with Mac NFD encoding (slow)" : "Pëerputhshmëri me kodim Mac NFD (e ngadaltë)",
    "Enable encryption" : "Aktivizoni fshehtëzim",
    "Enable previews" : "Aktivizoni paraparje",
    "Enable sharing" : "Aktivizo ndarjet",
    "Check for changes" : "Kontrollo për ndryshime",
    "Never" : "Kurrë",
    "Once every direct access" : "Çdo herë pas hyrjesh të drejtpërdrejta",
    "Read only" : "Vetëm i lexueshëm",
    "Disconnect" : "Shkëputu",
    "Admin defined" : "Përcaktuar nga përgjegjësi",
    "Saved" : "U ruajt",
    "Save" : "Ruaje",
    "Empty response from the server" : "Përgjigje e zbrazët prej serverit",
    "Couldn't access. Please log out and in again to activate this mount point" : "Nuk mund të ketë akses. Ju lutemi, dilni dhe hyni që të aktivizohet kjo pikë montimi",
    "Couldn't get the information from the remote server: {code} {type}" : "Nuk u morën dot të dhëna nga shërbyesi në largësi: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "S’u mor dot lista e pikave të jashtme të montimit: {type}",
    "There was an error with message: " : "Pati një gabim me këtë mesazh:",
    "External mount error" : "Gabim i jashtëm montimi",
    "external-storage" : "ruajtje-jashtme",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "S’u mor dot lista e pikave të montimit Windows network drive: përgjigje e zbrazët nga shërbyesi",
    "Please enter the credentials for the {mount} mount" : "Ju lutemi, jepni kredencialet për pikën e montimit {mount}",
    "Username" : "Emër përdoruesi",
    "Password" : "Fjalëkalim",
    "Credentials saved" : "Kredencialet u ruajtën",
    "Credentials saving failed" : "Ruajtja e kredencialeve dështoi",
    "Credentials required" : "Lypsen kredenciale",
    "Storage with ID \"%d\" not found" : "Ruajtja me ID \"%d\" nuk u gjet",
    "Invalid backend or authentication mechanism class" : "Mekanizëm shërbimi ose klasë mekanizmi mirëfilltësimi e palvefshme",
    "Invalid mount point" : "Pikë montimi e pavlefshme",
    "Objectstore forbidden" : "Objectstore e ndaluar",
    "Invalid storage backend \"%s\"" : "Mekanizëm shërbimi depozite i pavlefshëm \"%s\"",
    "Not permitted to use backend \"%s\"" : "I palejuar të përdorë mekanizmin e shërbimit \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "S’i lejohet të përdorë mekanizmin e mirëfilltësimit \"%s\"",
    "Unsatisfied backend parameters" : "Parametra mekanizmi shërbimi të paplotësuar",
    "Unsatisfied authentication mechanism parameters" : "Parametra mekanizmi mirëfilltësimi të papërmbushur",
    "Insufficient data: %s" : "Të dhëna të pamjaftueshme: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Ruajtja me ID \"%d\" nuk është i editueshëm nga përdorues",
    "Access key" : "Kyç hyrjesh",
    "Secret key" : "Kyç i fshehtë",
    "Builtin" : "I brendshëm",
    "None" : "Asnjë",
    "OAuth1" : "OAuth1",
    "App key" : "Kyç aplikacioni",
    "App secret" : "E fshehtë aplikacioni",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID klienti",
    "Client secret" : "E fshehtë klienti",
    "Tenant name" : "Emër qiraxhiu",
    "Identity endpoint URL" : "Identifiko pikëmbarimin URL",
    "Domain" : "Përkatësi",
    "Rackspace" : "Rackspace",
    "API key" : "Kyç API",
    "Global credentials" : "Kredenciale globale",
    "Log-in credentials, save in database" : "Kredencialet e identifikimit, ruaji në bazën e të dhënave",
    "Username and password" : "Emër përdoruesi dhe fjalëkalim",
    "Log-in credentials, save in session" : "Kredenciale hyrjesh, ruaji për sesion",
    "User entered, store in database" : "Përdoruesi u identifikua, ruaj në bazë të dhënash",
    "RSA public key" : "Kyç publik RSA ",
    "Public key" : "Kyç publik",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Strehëemër",
    "Port" : "Portë",
    "Region" : "Rajon",
    "Enable SSL" : "Aktivizo SSL-në",
    "Enable Path Style" : "Aktivizo Stile Shtegu",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Nëndosje e largët",
    "Secure https://" : "https:// e sigurt",
    "FTP" : "FTP",
    "Host" : "Strehë",
    "Secure ftps://" : "ftps:// e sigurt",
    "Local" : "Vendore",
    "Location" : "Vendndodhje",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Rrënjë",
    "SFTP with secret key login" : "SFTP me hyrje me kyç të fshehtë",
    "Share" : "Ndajeni me të tjerët",
    "Show hidden files" : "Shfaq skedarët e fshehur",
    "Username as share" : "Emër përdoruesi si emër ndarjeje",
    "OpenStack Object Storage" : "Depozitë OpenStack Object",
    "Service name" : "Emër shërbimi",
    "Request timeout (seconds)" : "Kohë skadimi kërkese (sekonda)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Mbështetja e cURL në PHP nuk është e instaluar ose e aktivizuar. Lidhja e %s nuk është e mundur. Ju lutemi kërkojini administratorin të sistemit tuaj që ta instaloj.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Mbështetja e FTP në PHP nuk është e aktivizuar ose instaluar.Lidhja e %s nuk është e mundur.Ju lutem kërkojini administratorit të sistemit tuaj që ta instalojë.",
    "External storage support" : "Suport i kujtesë së jashtme",
    "Name" : "Emër",
    "Storage type" : "Lloj depozite",
    "Scope" : "Shtrirje",
    "Open documentation" : "Dokumentacion i hapur",
    "Folder name" : "Emër dosjeje",
    "Authentication" : "Mirëfilltësim",
    "Configuration" : "Formësim",
    "Available for" : "E gatshme për",
    "Add storage" : "Shtoni depozitë",
    "Advanced settings" : "Rregullime të mëtejshme",
    "Allow users to mount external storage" : "Lejoju përdoruesve të montojnë depozita të jashtme"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.11.tgz: nextcloud/apps/files_external/l10n/sq.js <==
OC.L10N.register(
    "files_external",
    {
    "Compatibility with Mac NFD encoding (slow)" : "Pëerputhshmëri me kodim Mac NFD (e ngadaltë)",
    "Enable encryption" : "Aktivizoni fshehtëzim",
    "Enable previews" : "Aktivizoni paraparje",
    "Enable sharing" : "Aktivizo ndarjet",
    "Check for changes" : "Kontrollo për ndryshime",
    "Never" : "Kurrë",
    "Once every direct access" : "Çdo herë pas hyrjesh të drejtpërdrejta",
    "Read only" : "Vetëm i lexueshëm",
    "Disconnect" : "Shkëputu",
    "Admin defined" : "Përcaktuar nga përgjegjësi",
    "Saved" : "U ruajt",
    "Save" : "Ruaje",
    "Storage with ID \"%d\" not found" : "Ruajtja me ID \"%d\" nuk u gjet",
    "Invalid backend or authentication mechanism class" : "Mekanizëm shërbimi ose klasë mekanizmi mirëfilltësimi e palvefshme",
    "Invalid mount point" : "Pikë montimi e pavlefshme",
    "Objectstore forbidden" : "Objectstore e ndaluar",
    "Invalid storage backend \"%s\"" : "Mekanizëm shërbimi depozite i pavlefshëm \"%s\"",
    "Not permitted to use backend \"%s\"" : "I palejuar të përdorë mekanizmin e shërbimit \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "S’i lejohet të përdorë mekanizmin e mirëfilltësimit \"%s\"",
    "Unsatisfied backend parameters" : "Parametra mekanizmi shërbimi të paplotësuar",
    "Unsatisfied authentication mechanism parameters" : "Parametra mekanizmi mirëfilltësimi të papërmbushur",
    "Insufficient data: %s" : "Të dhëna të pamjaftueshme: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Ruajtja me ID \"%d\" nuk është i editueshëm nga përdorues",
    "Access key" : "Kyç hyrjesh",
    "Secret key" : "Kyç i fshehtë",
    "Builtin" : "I brendshëm",
    "None" : "Asnjë",
    "OAuth1" : "OAuth1",
    "App key" : "Kyç aplikacioni",
    "App secret" : "E fshehtë aplikacioni",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID klienti",
    "Client secret" : "E fshehtë klienti",
    "Username" : "Emër përdoruesi",
    "Password" : "Fjalëkalim",
    "Tenant name" : "Emër qiraxhiu",
    "Identity endpoint URL" : "Identifiko pikëmbarimin URL",
    "Domain" : "Përkatësi",
    "Rackspace" : "Rackspace",
    "API key" : "Kyç API",
    "Global credentials" : "Kredenciale globale",
    "Log-in credentials, save in database" : "Kredencialet e identifikimit, ruaji në bazën e të dhënave",
    "Username and password" : "Emër përdoruesi dhe fjalëkalim",
    "Log-in credentials, save in session" : "Kredenciale hyrjesh, ruaji për sesion",
    "User entered, store in database" : "Përdoruesi u identifikua, ruaj në bazë të dhënash",
    "RSA public key" : "Kyç publik RSA ",
    "Public key" : "Kyç publik",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Strehëemër",
    "Port" : "Portë",
    "Region" : "Rajon",
    "Enable SSL" : "Aktivizo SSL-në",
    "Enable Path Style" : "Aktivizo Stile Shtegu",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Nëndosje e largët",
    "Secure https://" : "https:// e sigurt",
    "FTP" : "FTP",
    "Host" : "Strehë",
    "Secure ftps://" : "ftps:// e sigurt",
    "Local" : "Vendore",
    "Location" : "Vendndodhje",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Rrënjë",
    "SFTP with secret key login" : "SFTP me hyrje me kyç të fshehtë",
    "Share" : "Ndajeni me të tjerët",
    "Show hidden files" : "Shfaq skedarët e fshehur",
    "Username as share" : "Emër përdoruesi si emër ndarjeje",
    "OpenStack Object Storage" : "Depozitë OpenStack Object",
    "Service name" : "Emër shërbimi",
    "Request timeout (seconds)" : "Kohë skadimi kërkese (sekonda)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Mbështetja e cURL në PHP nuk është e instaluar ose e aktivizuar. Lidhja e %s nuk është e mundur. Ju lutemi kërkojini administratorin të sistemit tuaj që ta instaloj.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Mbështetja e FTP në PHP nuk është e aktivizuar ose instaluar.Lidhja e %s nuk është e mundur.Ju lutem kërkojini administratorit të sistemit tuaj që ta instalojë.",
    "External storage" : "Depozitë e jashtme",
    "External storage support" : "Suport i kujtesë së jashtme",
    "External mount error" : "Gabim i jashtëm montimi",
    "Storage type" : "Lloj depozite",
    "Unknown" : "I panjohur",
    "Scope" : "Shtrirje",
    "Personal" : "Personale",
    "System" : "Sistem",
    "Open documentation" : "Dokumentacion i hapur",
    "Folder name" : "Emër dosjeje",
    "Authentication" : "Mirëfilltësim",
    "Configuration" : "Formësim",
    "Available for" : "E gatshme për",
    "Add storage" : "Shtoni depozitë",
    "Advanced settings" : "Rregullime të mëtejshme",
    "Allow users to mount external storage" : "Lejoju përdoruesve të montojnë depozita të jashtme",
    "Grant access" : "Akordoji hyrje",
    "Error configuring OAuth1" : "Gabim gjatë formësimit të OAuth1",
    "Please provide a valid app key and secret." : "Ju lutemi jepni një kyç dhe një të fshehtë aplikacioni të vlefshme.",
    "Error configuring OAuth2" : "Gabim gjatë formësimit të OAuth2",
    "Generate keys" : "Prodho kyçe",
    "Error generating key pair" : "Gabim gjatë prodhimit të çiftit të kyçeve",
    "Empty response from the server" : "Përgjigje e zbrazët prej serverit",
    "Couldn't access. Please log out and in again to activate this mount point" : "Nuk mund të ketë akses. Ju lutemi, dilni dhe hyni që të aktivizohet kjo pikë montimi",
    "Couldn't get the information from the remote server: {code} {type}" : "Nuk u morën dot të dhëna nga shërbyesi në largësi: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "S’u mor dot lista e pikave të jashtme të montimit: {type}",
    "There was an error with message: " : "Pati një gabim me këtë mesazh:",
    "external-storage" : "ruajtje-jashtme",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "S’u mor dot lista e pikave të montimit Windows network drive: përgjigje e zbrazët nga shërbyesi",
    "Please enter the credentials for the {mount} mount" : "Ju lutemi, jepni kredencialet për pikën e montimit {mount}",
    "Credentials saved" : "Kredencialet u ruajtën",
    "Credentials saving failed" : "Ruajtja e kredencialeve dështoi",
    "Credentials required" : "Lypsen kredenciale",
    "Name" : "Emër"
},
"nplurals=2; plural=(n != 1);");
